@@ -1,4 +1,10 @@
 import copy
+import os.path
+import re
+import subprocess
+import tempfile
+
+import yaml
 from semantic_version import Version
 
 from cx_releaser.src.docker_registry import AwsRegistry
@@ -36,8 +42,6 @@ class Release:
         if self.on_repo_not_exist == 'create':
             self.registry_client.get_or_create(self.name)
 
-
-
     def get_equal_tags_from_remote(self, hash_filter='', images=None, with_hash=False):
         equal_tags = []
         hashes = self.registry_client.get_images_on_unique_hash(self.name, hash_filter=hash_filter, images=images)
@@ -260,3 +264,71 @@ class Release:
 
     def __lt__(self, other):
         return self.name == other.name and self.version_sem() < other.version_sem()
+
+
+class DockerComposeReleaseTrigger:
+    REGISTRY = 'DOCKER_REGISTRY'
+    VERSION = 'VERSION'
+
+    def __init__(self, path, release: Release = None, services=None):
+        self.path = path
+        self.release = release
+        if services and len(services) == 1 and 'all' in services:
+            self.services = None
+        else:
+            self.services = services
+        with open(path, 'r') as yml:
+            self.raw_content = yml.read()
+
+    def _prepare_content(self):
+        new_content = self.raw_content
+        if self.release:
+            new_content = re.sub('\${VERSION.*?}', self.release.version, self.raw_content, re.MULTILINE|re.DOTALL)
+            new_content = re.sub('\${DOCKER_REGISTRY.*?}',
+                                 self.release.registry_client.registry_name, new_content, re.MULTILINE)
+        op = yaml.load(new_content, yaml.FullLoader)
+        images = []
+
+        for service, data in op['services'].items():
+            if self.services:
+                if service in self.services:
+                    images.append(data['image'])
+            else:
+                images.append(data['image'])
+
+        return new_content, images
+
+    def build(self, extra_cmd=''):
+        extra_cmd = extra_cmd or '' + ' '
+        content, images = self._prepare_content()
+        if self.services:
+            extra_cmd += ' '.join(self.services)
+        with tempfile.NamedTemporaryFile(mode='w+', dir=os.path.dirname(self.path)) as tp:
+            tp.write(content)
+            tp.seek(0)
+            cmd = subprocess.Popen([f'docker-compose -f {tp.name} build {extra_cmd}'],
+                                    stderr=subprocess.PIPE,
+                                    stdout=subprocess.PIPE, shell=True)
+            stdout, stderr = cmd.communicate()
+            print(stdout.decode())
+            print(stderr.decode())
+            return stdout, stderr
+
+    def get_releases(self):
+        content, images = self._prepare_content()
+        releases = []
+        for image in images:
+            name = re.search('/([^:]+):', image).group(1)
+            nw_releas = copy.copy(self.release)
+            nw_releas.name = name
+            nw_releas.local_name = image
+            releases.append(nw_releas)
+        return releases
+
+    def get_image_names(self):
+        content, images = self._prepare_content()
+        names = []
+        for image in images:
+            name = re.search('/([^:]+):', image).group(1)
+            names.append(name)
+        return names
